By default, all samples that have no explicit parent are children of the
inferred root sample. You can customize the parent-child relationships by
modifying the parent column in the samples data frame before plotting.
You can also modify the relationships using the set_parents function.
For example, if you have three samples, A, B, and C, they will have the
following relationships by default:
Root
/ | \
A B C
With the explicit parents, you can customize the relationships:
tables |>
set_parents(list(
# The parent of C is B
C = "B"
) |>
jellyfisher()
Root
/ \
A B
\
C